pyxmpp2.jid

Package pyxmpp2 :: Module jid |
[hide private]

# Module jid

jid -- XMPP address handling

Normative reference:
  - RFC 6122

Classes | [hide private]
| JID JID.

Functions | [hide private]
are_domains_equal(domain1, domain2) Compare two International Domain Names. |

Function Details | [hide private]

### are_domains_equal(domain1, domain2) |
Compare two International Domain Names. Parameters: `domain1` (`unicode`) - domains name to compare `domain2` (`unicode`) - domains name to compare Returns: True `domain1` and `domain2` are equal as domain names.